
full <- lm(response ~ ., data = data.frame(active_set))

response_power <- powerTransform(full)

rawdata[,phenotype]<-(rawdata[,phenotype])^response_power$lambda

response <- rawdata[,phenotype]

maindir <- getwd()

dirname <- paste("./",runid,"-results",sep="")

dir.create(dirname)

setwd(dirname)

full <- lm(response ~ ., data = data.frame(active_set))

full.stdres<-resid(full)

# text and tabular output

title1 <- paste("######################## ",runid," - ",phenotype," ##########################")

title2 <- paste("########## response power transform = ",response_power$lambda," ##########")

separator <- "******************************************************"

fn_main <- paste(runid," - analysis results.txt",sep="")

write.table(title1, file = fn_main, append = FALSE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(title2, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(summary(full))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(Anova(full))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(shapiro.test(full.stdres))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(ncvTest(full))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(durbinWatsonTest(full))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(powerTransform(full,family="yjPower"))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(calc.relimp(full,type=c("lmg","pmvd"),rela=TRUE))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

boot <- boot.relimp(full, b = 1000, type = c("lmg", 
  "last", "first", "pratt"), rank = TRUE, 
  diff = TRUE, rela = TRUE)

out<-capture.output(booteval.relimp(boot))
write.table(out, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn_main, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

# graphical output

fn<-paste(runid," - Normal Residual Plot.png",sep="")
png(file=fn, width = 600, height = 600)
qqnorm(full.stdres,ylab="Standardized Residuals",xlab="Normal Scores",
main="Linear Regression Residuals") 
qqline(full.stdres)
 
fn<-paste(runid," - relaimpo plot.png",sep="")
png(file=fn, width = 600, height = 600)
plot(booteval.relimp(boot,sort=TRUE))

avPlots(full)
cutoff <- 4/nrow(active_set)
fn<-paste(runid," - avplots.png",sep="")
png(file=fn, width = 600, height = 600)
plot(full, which=4, cook.levels=cutoff)

fn<-paste(runid," - influenceplot.png",sep="")
png(file=fn, width = 600, height = 600)
influencePlot(full,	id.method="identify", main="Influence Plot",
sub="Circle size is proportial to Cook's Distance" )

fn<-paste(runid," - effectplots.png",sep="")
png(file=fn, width = 600, height = 600)
plot(allEffects(full))

fn<-paste(runid," - residualplots.png",sep="")
png(file=fn, width = 600, height = 600)
residualPlots(full)

fn<-paste(runid," - marginalmodelplots.png",sep="")
png(file=fn, width = 600, height = 600)
marginalModelPlots(full)

fn<-paste(runid," - influenceindexplots.png",sep="")
png(file=fn, width = 600, height = 600)
influenceIndexPlot(full,id.n=5)

fn<-paste(runid," - componentplusresidualplots.png",sep="")
png(file=fn, width = 600, height = 600)
crPlots(full,order=2)

fn<-paste(runid," - spreadlevelplot.png",sep="")
png(file=fn, width = 600, height = 600)
spreadLevelPlot(full)

rf <- randomForest(response ~ .,
      data=active_set, 
      ntree=1500,
      mtry=3,
      importance=TRUE,
      na.action=na.omit,
      replace=TRUE)

for (ipred in 1:length(predictors))
{
fn<-paste(runid," - Partial Dependence Plot for ",predictors[ipred],".png",sep="")
png(file=fn, width = 600, height = 600)
partialPlot(rf,databind,predictors[ipred],
w, plot = TRUE, add = FALSE,
rug = TRUE, xlab=predictors[ipred], ylab=phenotype,
main=paste("Partial Dependence on",predictors[ipred]))
}

p_unadj <- summary(step)$coefficients[,4]

col0 <- p_unadj
col1 <- p.adjust(col0,method="bonferroni")
col2 <- p.adjust(col0,method="holm")
col3 <- p.adjust(col0,method="BH")

p_adj <- data.frame(col0,col1,col2,col3)

names(p_adj)<-c(
'Unadjusted',
'Bonferroni',
'H-B',
'B-H'
)

fn_p  <-paste(input_data[itable,1],"_adjusted_p-values_new_analyses.csv",sep="")

write.csv(p_adj,file=fn_p)

fn <- paste(runid,".RData",sep="")
save.image(file=fn)

setwd(maindir)

target <- paste(runid,".r",sep="")

dest <- paste(dirname,"/",target,sep="")

file.copy(target,dest,overwrite=TRUE)





