library(car)
library(e1071)
library(effects)
library(ggbiplot)
library(lattice)
library(randomForest)
library(rattle)
library(readstata13)
library(relaimpo)
library(RGtk2)
library(RGtk2Extras)

rm(list = ls())
options(warn=-1)

runid <- 'directed_SR-run096'

phenotype <- 'USDF'

predictors <- c(
'PWTP',
'OIWS',
'UWS',
'IS',
'FBH',
'HW'
)

rawdata<-read.csv(file="who_data_master_core_current.csv",header=TRUE,sep=",")

core_variables <- c(
'Region',
'Country',
'Population', 
'UWD',
'USD',
'UHD',
'WandSD',
'WSandHD',
'PWTP',
'OIWS',
'UWS',
'IS',
'FBH',
'HW',
'UWDF',
'USDF',
'UHDF',
'WandSDF',
'WSandHDF',
'UWDF_q',
'USDF_q',
'UHDF_q',
'WandSDF_q',
'WSandHDF_q'
)

temp0 <- rawdata[which(rawdata[,phenotype] != 0),]

temp <- temp0[which(temp0$Country != "DRCongo"),]

rawdata <- temp

for(ivar in 1:length(predictors))
{
rawdata[,predictors[ivar]]<-sqrt(rawdata[,predictors[ivar]])
}

response <- rawdata[,phenotype]

active_set <- rawdata[,predictors]

databind <- cbind(active_set,response)

colnames(databind) <- c(predictors,phenotype)

full <- lm(response ~ ., data = data.frame(active_set))

response_power <- powerTransform(full)

rawdata[,phenotype]<-(rawdata[,phenotype])^response_power$lambda

response <- rawdata[,phenotype]

full <- lm(response ~ ., data = data.frame(active_set))

null <- lm(response ~ 1, data = data.frame(active_set))

#########################################################################################################
#
#  stepAIC - Forward ; all SR methods yield the same best model
#
#########################################################################################################

fn <- paste("stepAIC - Forward.txt",sep="")
step<-stepAIC(null, scope=list(lower=null, upper=full), direction="forward")

out<-capture.output(summary(step))
write.table(out, file = fn, append = FALSE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("response power is ",response_power$lambda,"\n")

p_unadj <- summary(step)$coefficients[,4]

col0 <- p_unadj
col1 <- p.adjust(col0,method="bonferroni")
col2 <- p.adjust(col0,method="holm")
col3 <- p.adjust(col0,method="BH")

p_adj <- data.frame(col1,col2,col3)

names(p_adj)<-c(
'Bonferroni',
'H-B',
'B-H'
)

augmented <- cbind(summary(step)$coefficients,p_adj)

fn  <-paste("USDF_directed_SR - run096 - adjusted_p-values output.txt",sep="")

separator <- "******************************************************"

out<-capture.output(augmented)

write.table(out, file = fn, append = FALSE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("Adjusted R Squared is ",round(summary(step)$adj.r.squared,digits=4),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("F Statistic is ",round(summary(step)$fstatistic[1],digits=2),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

#####################################################################################
#
# Regressions with progressively smaller models, starting from stepAIC best model
#
#####################################################################################

full <- lm(response ~ IS + UWS + OIWS, data = data.frame(active_set))

p_unadj <- summary(full)$coefficients[,4]

col0 <- p_unadj
col1 <- p.adjust(col0,method="bonferroni")
col2 <- p.adjust(col0,method="holm")
col3 <- p.adjust(col0,method="BH")

p_adj <- data.frame(col1,col2,col3)

names(p_adj)<-c(
'Bonferroni',
'H-B',
'B-H'
)

augmented <- cbind(summary(full)$coefficients,p_adj)

out<-capture.output(augmented)

write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("Adjusted R Squared is ",round(summary(full)$adj.r.squared,digits=4),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("F Statistic is ",round(summary(full)$fstatistic[1],digits=2),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

full <- lm(response ~ IS + UWS, data = data.frame(active_set))

p_unadj <- summary(full)$coefficients[,4]

col0 <- p_unadj
col1 <- p.adjust(col0,method="bonferroni")
col2 <- p.adjust(col0,method="holm")
col3 <- p.adjust(col0,method="BH")

p_adj <- data.frame(col1,col2,col3)

names(p_adj)<-c(
'Bonferroni',
'H-B',
'B-H'
)

augmented <- cbind(summary(full)$coefficients,p_adj)

out<-capture.output(augmented)

write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("Adjusted R Squared is ",round(summary(full)$adj.r.squared,digits=4),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("F Statistic is ",round(summary(full)$fstatistic[1],digits=2),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

full <- lm(response ~ IS, data = data.frame(active_set))

p_unadj <- summary(full)$coefficients[,4]

col0 <- p_unadj
col1 <- p.adjust(col0,method="bonferroni")
col2 <- p.adjust(col0,method="holm")
col3 <- p.adjust(col0,method="BH")

p_adj <- data.frame(col1,col2,col3)

names(p_adj)<-c(
'Bonferroni',
'H-B',
'B-H'
)

augmented <- cbind(summary(full)$coefficients,p_adj)

out<-capture.output(augmented)

write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("Adjusted R Squared is ",round(summary(full)$adj.r.squared,digits=4),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-paste("F Statistic is ",round(summary(full)$fstatistic[1],digits=2),sep="")
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

write.table(separator, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")





