library(car)
library(e1071)
library(effects)
library(ggbiplot)
library(lattice)
library(randomForest)
library(rattle)
library(readstata13)
library(relaimpo)
library(RGtk2)
library(RGtk2Extras)

rm(list = ls())
options(warn=-1)

runid <- 'run096'

phenotype <- 'USDF'

predictors <- c(
'PWTP',
'OIWS',
'UWS',
'IS',
'FBH',
'HW'
)

rawdata<-read.csv(file="who_data_master_core_current.csv",header=TRUE,sep=",")

core_variables <- c(
'Region',
'Country',
'Population', 
'UWD',
'USD',
'UHD',
'WandSD',
'WSandHD',
'PWTP',
'OIWS',
'UWS',
'IS',
'FBH',
'HW',
'UWDF',
'USDF',
'UHDF',
'WandSDF',
'WSandHDF',
'UWDF_q',
'USDF_q',
'UHDF_q',
'WandSDF_q',
'WSandHDF_q'
)

temp0 <- rawdata[which(rawdata[,phenotype] != 0),]

temp <- temp0[which(temp0$Country != "DRCongo"),]

rawdata <- temp

for(ivar in 1:length(predictors))
{
rawdata[,predictors[ivar]]<-sqrt(rawdata[,predictors[ivar]])
}

response <- rawdata[,phenotype]

active_set <- rawdata[,predictors]

databind <- cbind(active_set,response)

colnames(databind) <- c(predictors,phenotype)

full <- lm(response ~ ., data = data.frame(active_set))

response_power <- powerTransform(full)

rawdata[,phenotype]<-(rawdata[,phenotype])^response_power$lambda

response <- rawdata[,phenotype]

maindir <- getwd()

dirname <- paste("./",runid,"-results",sep="")

dir.create(dirname)

setwd(dirname)

full <- lm(response ~ ., data = data.frame(active_set))

null <- lm(response ~ 1, data = data.frame(active_set))

#########################################################################################################
#
#  stepAIC - Forward
#
#########################################################################################################

fn <- paste("stepAIC - Forward.txt",sep="")
step<-stepAIC(null, scope=list(lower=null, upper=full), direction="forward")

out<-capture.output(summary(step))
write.table(out, file = fn, append = FALSE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepAIC Forward completed ... ","\n")

#########################################################################################################
#
#  stepAIC - Backward
#
#########################################################################################################

fn <- paste("stepAIC - Backward.txt",sep="")
step<-stepAIC(full,direction="backward")

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepAIC backward completed ... ","\n")

#########################################################################################################
#
#  stepAIC - 2 way
#
#########################################################################################################

fn <- paste("stepAIC - 2 way.txt",sep="")
step<-stepAIC(null, scope = list(upper=full), direction="both")

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepAIC 2 way completed ... ","\n")

#########################################################################################################
#
#  stepBIC - forward
#
#########################################################################################################

fn <- paste("stepBIC - forward.txt",sep="")
step<-step(null,scope=list(upper=full,lower=null),direction=c("forward"),k=log(nrow(databind)))

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepBIC forward completed ... ","\n")

#########################################################################################################
#
#  stepBIC - backward
#
#########################################################################################################

fn <- paste("stepBIC - backward.txt",sep="")
step<-step(full,scope=list(upper=full,lower=null),direction=c("backward"),k=log(nrow(databind)))

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepBIC backward completed ... ","\n")

#########################################################################################################
#
#  stepBIC - 2 way start full
#
#########################################################################################################

fn <- paste("stepBIC - 2 way start full.txt",sep="")
step<-step(full,scope=list(upper=full,lower=null),direction=c("both"),k=log(nrow(databind)))

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepBIC 2 way start full completed ... ","\n")

#########################################################################################################
#
#  stepBIC - 2 way start null
#
#########################################################################################################

fn <- paste("stepBIC - 2 way start null.txt",sep="")
step<-step(null,scope=list(upper=full,lower=null),direction=c("both"),k=log(nrow(databind)))

out<-capture.output(summary(step))
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

out<-capture.output(step$anova)
write.table(out, file = fn, append = TRUE, quote = FALSE, sep = " ",
eol = "\n", na = "NA", dec = ".", row.names = FALSE,
col.names = FALSE, qmethod = c("escape", "double"),
fileEncoding = "")

cat("stepBIC 2 way start null completed ... ","\n")

fn <- paste(runid,".RData",sep="")
save.image(file=fn)

setwd(maindir)

target <- paste(runid,".r",sep="")

dest <- paste(dirname,"/",target,sep="")

file.copy(target,dest,overwrite=TRUE)

graphics.off()

